@@ -41,3 +41,8 @@ def test_matplotlib_default_colormap_plot_kbc():
     from colorcet.plotting import swatch
     fig = hv.render(swatch('kbc'), backend='matplotlib')
     return fig
+
+@pytest.mark.parametrize('k,v', list(cc.cm.items()))
+def test_get_cm(k, v):
+    import matplotlib.cm as mcm
+    assert mcm.get_cmap('cet_' + k) is v
